require 'spec_helper'
require 'migrator'
require 'db_obfuscation/database'

module DbObfuscation
  module Cli
    describe Migrator do
      describe '.migrate' do
        before do
          system("dropdb -e obfuscation_test")
          system("createdb -e obfuscation_test")
        end

        it 'creates table in the test database' do
          expect(DbObfuscation::DB.tables).to eq []

          db_yml = File.expand_path('../../config/database.yml',
                                    __FILE__)
          migration_path = File.expand_path('../../test_db_setup/migrations',
                                            __FILE__)

          described_class.migrate(db_yml, migration_path)

          expect(DbObfuscation::DB.tables).to include :table_1
          expect(DbObfuscation::DB.tables).to include :table_2
          expect(DbObfuscation::DB.tables).to include :truncation_table_1
          expect(DbObfuscation::DB.tables).to include :whitelisted_table_1
        end
      end

      describe '.down_migrate' do
        before do
          system("dropdb -e obfuscation_test")
          system("createdb -e obfuscation_test")
        end

        it 'creates table in the test database' do
          db_yml = File.expand_path('../../config/database.yml',
                                    __FILE__)
          migration_path = File.expand_path('../../test_db_setup/migrations',
                                            __FILE__)

          described_class.migrate(db_yml, migration_path)
          expect(DbObfuscation::DB.tables).to include :table_1
          expect(DbObfuscation::DB.tables).to include :table_2
          expect(DbObfuscation::DB.tables).to include :truncation_table_1
          expect(DbObfuscation::DB.tables).to include :whitelisted_table_1

          described_class.down_migrate(db_yml, migration_path)

          expect(DbObfuscation::DB.tables).to eq([:schema_info])

          #rescue operation to keep the test db in a clean state
          described_class.migrate(db_yml, migration_path)
        end
      end
    end
  end
end
