require 'spec_helper'
require 'db_obfuscation/config'

module DbObfuscation
  describe Config do

    it 'looks for database configuration file' do
      dir = DbObfuscation.config_dir
      expect(described_class.config_path).to eq(dir)
    end

    it 'takes database configuration file from users' do
      described_class.config_path = '/var'
      expect(described_class.config_path).to eq(Pathname.new('/var'))
    end

    context '.db_config' do
      before do
        config_path = DbObfuscation.config_dir
        described_class.config_path = config_path
      end

      it 'loads the configuration file' do
        db_config = { "database" => 'obfuscation_test' }
        expect(described_class.db_config).to include db_config
      end

      it 'provides database information from the configuration file' do
        db_config = described_class.db_config
        expect(db_config['username']).to eq('ccUser')
        expect(db_config['database']).to eq('obfuscation_test')
      end
    end

    context '.truncation_patterns' do
      it 'returns collection of truncation patterns' do
        patterns = described_class.truncation_patterns
        expect(patterns).to include(:truncation_table_1)
      end
    end

    context '.whitelisted_tables' do
      it 'returns collection of tables names' do
        whitelisted_tables = described_class.whitelisted_tables
        expect(whitelisted_tables).to include('whitelisted_table_1')
      end
    end

    context '.table_strategies' do
      it 'returns all the obfuscation strategies for tables' do
        strategies = described_class.table_strategies
        phone_masking_technique = strategies['table_1']['field_1']
        expect(phone_masking_technique).to eq(:first_name_strategy)

        address_masking_technique = strategies['table_2']['date_field']
        expect(address_masking_technique).to eq(:date_strategy)
      end
    end
  end
end
