require 'spec_helper'
require 'db_obfuscation/filtering/column'

module DbObfuscation::Filtering
  describe Column do
    context '.columns_type' do
      it 'returns the column and types for the table' do
        column_types = {
          id: :integer,
          field_1: :string,
          field_2: :string,
          date_field: :date,
          created_at: :datetime,
          updated_at: :datetime,
          boolean_field: :boolean,
          integer_field: :integer
        }

        expect(described_class.columns_type('table_1')).to eq(column_types)
      end
    end

    describe '.type?' do
      let(:expected_column_type) { [:string] }
      let(:column_type) { :string }

      it 'returns true when types matches' do
        column_type = :string
        expect(described_class.type?(expected_column_type, column_type)).to eq true
      end

      it 'returns false when types does not match' do
        column_type = :int
        expect(described_class.type?(expected_column_type, column_type)).to eq false
      end
    end

    describe '.polymorphic?' do
      it 'returns true when the column name is polymorphic association column' do
        column_name = 'column_name_type'
        expect(described_class.polymorphic?(column_name)).to eq true
      end

      it 'returns false when the column name is not polymorphic association column' do
        column_name = 'simple_column_name'
        expect(described_class.polymorphic?(column_name)).to eq false
      end
    end

    describe '.ending_in_id?' do
      it 'returns true if the column name ends in "id"' do
        column_name = 'simple_column_name_id'
        expect(described_class.ending_in_id?(column_name)).to eq true
      end

      it 'returns false if the column name does not ends in "id"' do
        column_name = 'simple_column_name'
        expect(described_class.ending_in_id?(column_name)).to eq false
      end
    end

    describe '.filter' do
      it 'returns the column name if it meets all criterias' do
        expect(described_class.filter('name','type','type')).to eq 'name'
      end

      context 'criterias' do
        it 'filters out polymorphic association columns' do
          expect(described_class.filter('polymorphic_type','type','type')).to be_nil
        end

        it 'filters out columns name ending in id' do
          expect(described_class.filter('message_id','type','type')).to be_nil
        end

        it 'filters out columns with no matching types' do
          expect(described_class.filter('message', :type, [:expected_type])).to be_nil
        end
      end
    end
  end
end
