require 'spec_helper'
require 'db_obfuscation/filtering/truncation'

module DbObfuscation
  module Filtering
    describe Truncation do
      describe '.matches_patterns' do
        it 'returns the tables that are the same as patterns' do
          patterns = [:pattern_1, :pattern_2]
          tables = [ :pattern_1, :pattern_2, :non_pattern_1, :pattern_3]
          truncation_tables = described_class.matches_patterns(tables, patterns)
          expect(truncation_tables).to match_array [:pattern_1, :pattern_2]
        end

        it 'returns all the tables that start with the pattern followed by an underscore' do
          patterns = [:pattern_1, :pattern_2]
          tables = [ :pattern_1,
                     :pattern_2,
                     :pattern_1_table,
                     :non_pattern_1,
                     :pattern_3,
                     :pattern_1non_truncation_table]

          tables = described_class.matches_patterns(tables, patterns)
          expect(tables).to match_array [:pattern_1,
                                         :pattern_2,
                                         :pattern_1_table]

        end

        it 'does not have any duplicate table names' do
          patterns = [:pattern_1, :pattern_1]
          tables = [:pattern_1]

          tables = described_class.matches_patterns(tables, patterns)
          expect(tables).to match_array [:pattern_1]
        end
      end
    end
  end
end
