require 'spec_helper'
require 'db_obfuscation/filtering'
module DbObfuscation
  describe Filtering do

    describe 'obfuscation_config' do
      it 'returns the obfuscation strategies for every table in the database' do
        config = {
          table_1: {
            field_1: :first_name_strategy,
            field_2: :default_strategy,
            date_field: :date_strategy
          },
          table_2: {
            field_1: :default_strategy,
            date_field: :date_strategy
          },
          table_without_any_user_defined_obfuscation_strategies: {
            field_1: :default_strategy,
            field_2: :default_strategy
          }
        }

        expect(described_class.obfuscation_config([:string])).to eq config
      end

      it 'includes table configuations without any user defined table strategies' do
        config = described_class.obfuscation_config([:string])
        expect(config.keys).to include(:table_without_any_user_defined_obfuscation_strategies)
      end

      it 'does not include configuration for table that does not have obfuscatable columns' do
        config = described_class.obfuscation_config([:string])
        expect(config.keys).to_not include(:table_without_any_obfuscatable_columns)
        expect(config.keys).to include(:table_without_any_user_defined_obfuscation_strategies)
      end
    end
  end
end
