require 'spec_helper'
require 'db_obfuscation'
require 'db_obfuscation/truncation'

describe 'DbObfuscation' do
  around(:each) do |example|
    DbObfuscation::DB.transaction(rollback: :always) do
      example.run
    end
  end

  it 'replaces existing data columns with fake data' do
    record = DbObfuscation::DB[:table_1].first
    original_value = record[:field_1]
    expect(original_value).to eq 'original_field_1_1'

    DbObfuscation.obfuscate(100)

    record = DbObfuscation::DB[:table_1].where(id: record[:id]).first
    obfuscated_value = record[:field_1]
    expect(obfuscated_value).to_not eq 'original_field_1_1'
  end

  it 'obfuscates date field when included in the config file' do
    record = DbObfuscation::DB[:table_1].first
    original_date = record[:date_field]
    expect(original_date.to_s).to eq '2001-01-01'

    DbObfuscation.obfuscate(100)

    record = DbObfuscation::DB[:table_1].where(id: record[:id]).first
    obfuscated_date = record[:date_field]
    expect(obfuscated_date.to_s).to_not eq '2001-01-01'
  end

  it 'does not obfuscate whitelisted column for a table' do
    record = DbObfuscation::DB[:table_2].first
    original_value = record[:field_2]
    expect(original_value).to eq 'original_field_2_1'

    DbObfuscation.obfuscate(100)

    record = DbObfuscation::DB[:table_2].where(id: record[:id]).first
    obfuscated_value = record[:field_2]
    expect(obfuscated_value).to eq 'original_field_2_1'
  end

  it 'does not obfuscate the whitelisted tables' do
    record = DbObfuscation::DB[:whitelisted_table_1].first
    original_value = record[:field_1]
    expect(original_value).to eq 'whitelisted_field_1_1'

    DbObfuscation.obfuscate(100)

    record = DbObfuscation::DB[:whitelisted_table_1].where(id: record[:id]).first
    obfuscated_value = record[:field_1]
    expect(obfuscated_value).to eq 'whitelisted_field_1_1'
  end

  it 'truncates the truncation table list' do
    original_data_count = DbObfuscation::DB[:truncation_table_1].count
    expect(original_data_count).to be > 0

    DbObfuscation::Truncation.truncate

    new_data_count = DbObfuscation::DB[:truncation_table_1].count
    expect(new_data_count).to eq 0
  end
end
